@@ -8,7 +8,7 @@ from muffin.plugins import BasePlugin
 from apiclient import APIClient
 
 
-__version__ = "1.1.2"
+__version__ = "1.1.3"
 __project__ = "muffin-apiclient"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
@@ -67,7 +67,7 @@ class Plugin(BasePlugin):
         """Shutdown self client."""
         await self.client.shutdown()
 
-    async def client_middleware(self, fn: T) -> T:
+    def client_middleware(self, fn: T) -> T:
         """Register a middleware."""
         client = t.cast(APIClient, self.client)
         return client.middleware(fn)
